@@ -5,7 +5,7 @@ import os
 from dotenv import load_dotenv
 
 
-def load_env_var(filepath: str) -> str:
+def load_env_var(filepath: str) -> (str, str):
     projectroot = os.path.dirname(os.path.dirname(os.path.realpath(filepath)))
 
     dotenv_path = os.path.join(projectroot, '.env')
@@ -13,4 +13,4 @@ def load_env_var(filepath: str) -> str:
     envtype = os.environ.get('ENV_TYPE', default='local')
     load_dotenv(dotenv_path + '.' + envtype)
 
-    return projectroot
+    return projectroot, envtype
